@@ -1,13 +1,13 @@
-use std::{io::{LineWriter, Read, stderr}, time::Duration};
+use std::{io::{LineWriter, stderr}, time::Duration};
 
-use anyhow::{Result, bail};
+use anyhow::Result;
 use crossterm::{cursor::{RestorePosition, SavePosition}, execute, style::Print, terminal::{disable_raw_mode, enable_raw_mode}};
 use scopeguard::defer;
-use tokio::{io::{AsyncReadExt, BufReader}, time::timeout};
+use tokio::time::sleep;
 use tracing::{debug, error, warn};
 use yazi_shared::Either;
 
-use crate::{Adapter, Brand, Mux, TMUX, Unknown};
+use crate::{Adapter, AsyncStdin, Brand, Mux, TMUX, Unknown};
 
 #[derive(Clone, Copy, Debug)]
 pub struct Emulator {
@@ -17,40 +17,37 @@ pub struct Emulator {
 }
 
 impl Default for Emulator {
-	fn default() -> Self {
-		Self { kind: Either::Right(Unknown::default()), light: false, cell_size: None }
-	}
+	fn default() -> Self { Self::unknown() }
 }
 
 impl Emulator {
-	pub fn detect() -> Self {
-		if let Some(brand) = Brand::from_env() {
-			Self { kind: Either::Left(brand), ..Self::detect_base().unwrap_or_default() }
-		} else {
-			Self::detect_full().unwrap_or_default()
-		}
-	}
-
-	pub fn detect_full() -> Result<Self> {
+	pub fn detect() -> Result<Self> {
 		defer! { disable_raw_mode().ok(); }
 		enable_raw_mode()?;
 
+		let resort = Brand::from_env();
+		let kgp_seq = if resort.is_none() {
+			Mux::csi("\x1b_Gi=31,s=1,v=1,a=q,t=d,f=24;AAAA\x1b\\")
+		} else {
+			"".into()
+		};
+
 		execute!(
 			LineWriter::new(stderr()),
 			SavePosition,
-			Print(Mux::csi("\x1b_Gi=31,s=1,v=1,a=q,t=d,f=24;AAAA\x1b\\")), // Detect KGP
-			Print(Mux::csi("\x1b[>q")),                                    // Request terminal version
-			Print("\x1b[16t"),                                             // Request cell size
-			Print("\x1b]11;?\x07"),                                        // Request background color
-			Print(Mux::csi("\x1b[0c")),                                    // Request device attributes
+			Print(kgp_seq),             // Detect KGP
+			Print(Mux::csi("\x1b[>q")), // Request terminal version
+			Print("\x1b[16t"),          // Request cell size
+			Print("\x1b]11;?\x07"),     // Request background color
+			Print(Mux::csi("\x1b[0c")), // Request device attributes
 			RestorePosition
 		)?;
 
-		let resp = futures::executor::block_on(Self::read_until_da1());
+		let resp = Self::read_until_da1();
 		Mux::tmux_drain()?;
 
-		let kind = if let Some(brand) = Brand::from_csi(&resp) {
-			Either::Left(brand)
+		let kind = if let Some(b) = Brand::from_csi(&resp).or(resort) {
+			Either::Left(b)
 		} else {
 			Either::Right(Unknown {
 				kgp:   resp.contains("\x1b_Gi=31;OK"),
@@ -65,6 +62,10 @@ impl Emulator {
 		})
 	}
 
+	pub const fn unknown() -> Self {
+		Self { kind: Either::Right(Unknown::default()), light: false, cell_size: None }
+	}
+
 	pub fn adapters(self) -> &'static [Adapter] {
 		match self.kind {
 			Either::Left(brand) => brand.adapters(),
@@ -84,7 +85,7 @@ impl Emulator {
 
 		// I really don't want to add this,
 		// But tmux and ConPTY sometimes cause the cursor position to get out of sync.
-		if *TMUX || cfg!(windows) {
+		if TMUX.get() || cfg!(windows) {
 			execute!(buf, SavePosition, MoveTo(x, y), Show)?;
 			execute!(buf, MoveTo(x, y), Show)?;
 			execute!(buf, MoveTo(x, y), Show)?;
@@ -94,7 +95,7 @@ impl Emulator {
 		}
 
 		let result = cb(&mut buf);
-		if *TMUX || cfg!(windows) {
+		if TMUX.get() || cfg!(windows) {
 			queue!(buf, Hide, RestorePosition)?;
 		} else {
 			queue!(buf, RestorePosition)?;
@@ -104,74 +105,40 @@ impl Emulator {
 		result
 	}
 
-	pub async fn read_until_da1() -> String {
-		let mut buf: Vec<u8> = Vec::with_capacity(200);
-		let read = async {
-			let mut stdin = BufReader::new(tokio::io::stdin());
-			loop {
-				let mut c = [0; 1];
-				if stdin.read(&mut c).await? == 0 {
-					bail!("unexpected EOF");
-				}
-				buf.push(c[0]);
-				if c[0] != b'c' || !buf.contains(&0x1b) {
-					continue;
-				}
-				if buf.rsplitn(2, |&b| b == 0x1b).next().is_some_and(|s| s.starts_with(b"[?")) {
-					break;
-				}
-			}
-			Ok(())
-		};
+	pub fn read_until_da1() -> String {
+		let h = tokio::spawn(Self::error_to_user());
+		let (buf, result) = AsyncStdin::default().read_until(Duration::from_millis(300), |b, buf| {
+			b == b'c'
+				&& buf.contains(&0x1b)
+				&& buf.rsplitn(2, |&b| b == 0x1b).next().is_some_and(|s| s.starts_with(b"[?"))
+		});
 
-		match timeout(Duration::from_secs(5), read).await {
-			Ok(Ok(())) => debug!("read_until_da1: {buf:?}"),
-			Err(e) => {
-				error!("read_until_da1 timed out: {buf:?}, error: {e:?}");
-				Self::error_to_user().ok();
-			}
-			Ok(Err(e)) => {
-				error!("read_until_da1 failed: {buf:?}, error: {e:?}");
-				Self::error_to_user().ok();
-			}
+		h.abort();
+		match result {
+			Ok(()) => debug!("read_until_da1: {buf:?}"),
+			Err(e) => error!("read_until_da1 failed: {buf:?}, error: {e:?}"),
+		}
+
+		String::from_utf8_lossy(&buf).into_owned()
+	}
+
+	pub fn read_until_dsr() -> String {
+		let (buf, result) = AsyncStdin::default().read_until(Duration::from_millis(100), |b, buf| {
+			b == b'n' && (buf.ends_with(b"\x1b[0n") || buf.ends_with(b"\x1b[3n"))
+		});
+
+		match result {
+			Ok(()) => debug!("read_until_dsr: {buf:?}"),
+			Err(e) => error!("read_until_dsr failed: {buf:?}, error: {e:?}"),
 		}
 		String::from_utf8_lossy(&buf).into_owned()
 	}
 
-	pub async fn read_until_dsr() -> String {
-		let mut buf: Vec<u8> = Vec::with_capacity(200);
-		let read = async {
-			let mut stdin = BufReader::new(tokio::io::stdin());
-			loop {
-				let mut c = [0; 1];
-				if stdin.read(&mut c).await? == 0 {
-					bail!("unexpected EOF");
-				}
-				buf.push(c[0]);
-				if c[0] == b'n' && (buf.ends_with(b"\x1b[0n") || buf.ends_with(b"\x1b[3n")) {
-					break;
-				}
-			}
-			Ok(())
-		};
-
-		match timeout(Duration::from_secs(5), read).await {
-			Ok(Ok(())) => debug!("read_until_dsr: {buf:?}"),
-			Err(e) => {
-				error!("read_until_dsr timed out: {buf:?}, error: {e:?}");
-				Self::error_to_user().ok();
-			}
-			Ok(Err(e)) => {
-				error!("read_until_dsr failed: {buf:?}, error: {e:?}");
-				Self::error_to_user().ok();
-			}
-		}
-		String::from_utf8_lossy(&buf).into_owned()
-	}
-
-	fn error_to_user() -> Result<()> {
+	async fn error_to_user() {
 		use crossterm::style::{Attribute, Color, Print, ResetColor, SetAttributes, SetForegroundColor};
-		crossterm::execute!(
+
+		sleep(Duration::from_millis(200)).await;
+		_ = crossterm::execute!(
 			std::io::stderr(),
 			SetForegroundColor(Color::Red),
 			SetAttributes(Attribute::Bold.into()),
@@ -183,36 +150,7 @@ impl Emulator {
 			Print(
 				"Please check your terminal environment as per: https://yazi-rs.github.io/docs/faq#trt\r\n"
 			),
-			//
-			SetAttributes(Attribute::Bold.into()),
-			SetAttributes(Attribute::Reverse.into()),
-			Print("Press any key to continue...\r\n"),
-			SetAttributes(Attribute::Reset.into()),
-		)?;
-
-		std::io::stdin().read_exact(&mut [0])?;
-		Ok(())
-	}
-
-	fn detect_base() -> Result<Self> {
-		defer! { disable_raw_mode().ok(); }
-		enable_raw_mode()?;
-
-		execute!(
-			LineWriter::new(stderr()),
-			Print("\x1b[16t"),      // Request cell size
-			Print("\x1b]11;?\x07"), // Request background color
-			Print("\x1b[0c"),       // Request device attributes
-		)?;
-
-		let resp = futures::executor::block_on(Self::read_until_da1());
-		Mux::tmux_drain()?;
-
-		Ok(Self {
-			light: Self::light_bg(&resp).unwrap_or_default(),
-			cell_size: Self::cell_size(&resp),
-			..Default::default()
-		})
+		);
 	}
 
 	fn cell_size(resp: &str) -> Option<(u16, u16)> {
