@@ -1,11 +1,12 @@
 use std::{collections::HashMap, path::Path, str::FromStr};
 
+use anyhow::Context;
 use indexmap::IndexSet;
 use serde::{Deserialize, Deserializer};
 use yazi_shared::MIME_DIR;
 
 use super::Opener;
-use crate::{open::OpenRule, Preset};
+use crate::{Preset, open::OpenRule};
 
 #[derive(Debug)]
 pub struct Open {
@@ -55,9 +56,11 @@ impl Open {
 }
 
 impl FromStr for Open {
-	type Err = toml::de::Error;
+	type Err = anyhow::Error;
 
-	fn from_str(s: &str) -> Result<Self, Self::Err> { toml::from_str(s) }
+	fn from_str(s: &str) -> Result<Self, Self::Err> {
+		toml::from_str(s).context("Failed to parse the [open] or [opener] section in your yazi.toml")
+	}
 }
 
 impl<'de> Deserialize<'de> for Open {
@@ -96,7 +99,7 @@ impl<'de> Deserialize<'de> for Open {
 
 		Ok(Self {
 			#[rustfmt::skip]
-			rules: Preset::mix(outer.open.rules, outer.open.prepend_rules, outer.open.append_rules).collect(),
+			rules: Preset::mix(outer.open.prepend_rules, outer.open.rules, outer.open.append_rules).collect(),
 			openers,
 		})
 	}
