@@ -1,7 +1,7 @@
 use std::path::Path;
 
 use serde::Deserialize;
-use yazi_shared::{event::Cmd, MIME_DIR};
+use yazi_shared::{MIME_DIR, event::Cmd};
 
 use crate::{Pattern, Priority};
 
@@ -26,16 +26,3 @@ impl Preloader {
 			|| self.name.as_ref().is_some_and(|p| p.match_path(path, mime == MIME_DIR))
 	}
 }
-
-#[derive(Debug, Clone)]
-pub struct PreloaderProps {
-	pub id:   u8,
-	pub name: String,
-	pub prio: Priority,
-}
-
-impl From<&Preloader> for PreloaderProps {
-	fn from(preloader: &Preloader) -> Self {
-		Self { id: preloader.idx, name: preloader.run.name.to_owned(), prio: preloader.prio }
-	}
-}
