@@ -9,19 +9,20 @@ use super::{Filetype, Flavor, Icons};
 
 #[derive(Deserialize, Serialize)]
 pub struct Theme {
-	pub flavor:     Flavor,
-	pub manager:    Manager,
-	mode:           Mode,
-	status:         Status,
-	pub which:      Which,
-	pub confirm:    Confirm,
-	pub spot:       Spot,
-	pub notify:     Notify,
-	pub pick:       Pick,
-	pub input:      Input,
-	pub completion: Completion,
-	pub tasks:      Tasks,
-	pub help:       Help,
+	pub flavor:  Flavor,
+	#[serde(rename = "manager")]
+	pub mgr:     Mgr, // TODO: Remove `serde(rename)`
+	pub mode:    Mode,
+	pub status:  Status,
+	pub which:   Which,
+	pub confirm: Confirm,
+	pub spot:    Spot,
+	pub notify:  Notify,
+	pub pick:    Pick,
+	pub input:   Input,
+	pub cmp:     Cmp,
+	pub tasks:   Tasks,
+	pub help:    Help,
 
 	// File-specific styles
 	#[serde(rename = "filetype", deserialize_with = "Filetype::deserialize", skip_serializing)]
@@ -35,7 +36,7 @@ impl FromStr for Theme {
 
 	fn from_str(s: &str) -> Result<Self, Self::Err> {
 		let theme: Self = toml::from_str(s).context("Failed to parse your theme.toml")?;
-		theme.manager.validate()?;
+		theme.mgr.validate()?;
 		theme.which.validate()?;
 
 		Ok(theme)
@@ -43,7 +44,7 @@ impl FromStr for Theme {
 }
 
 #[derive(Deserialize, Serialize, Validate)]
-pub struct Manager {
+pub struct Mgr {
 	cwd: Style,
 
 	// Hovered
@@ -80,7 +81,7 @@ pub struct Manager {
 }
 
 #[derive(Deserialize, Serialize)]
-struct Mode {
+pub struct Mode {
 	pub normal_main: Style,
 	pub normal_alt:  Style,
 
@@ -92,14 +93,10 @@ struct Mode {
 }
 
 #[derive(Deserialize, Serialize)]
-struct Status {
-	pub separator_open:  String,
-	pub separator_close: String,
-
-	// Progress
-	pub progress_label:  Style,
-	pub progress_normal: Style,
-	pub progress_error:  Style,
+pub struct Status {
+	pub overall:   Style,
+	pub sep_left:  StatusSep,
+	pub sep_right: StatusSep,
 
 	// Permissions
 	pub perm_sep:   Style,
@@ -107,6 +104,17 @@ struct Status {
 	pub perm_read:  Style,
 	pub perm_write: Style,
 	pub perm_exec:  Style,
+
+	// Progress
+	pub progress_label:  Style,
+	pub progress_normal: Style,
+	pub progress_error:  Style,
+}
+
+#[derive(Deserialize, Serialize)]
+pub struct StatusSep {
+	pub open:  String,
+	pub close: String,
 }
 
 #[derive(Deserialize, Serialize, Validate)]
@@ -124,10 +132,11 @@ pub struct Which {
 
 #[derive(Deserialize, Serialize)]
 pub struct Confirm {
-	pub border:     Style,
-	pub title:      Style,
-	pub content:    Style,
-	pub list:       Style,
+	pub border:  Style,
+	pub title:   Style,
+	pub content: Style,
+	pub list:    Style,
+
 	pub btn_yes:    Style,
 	pub btn_no:     Style,
 	pub btn_labels: [String; 2],
@@ -137,6 +146,9 @@ pub struct Confirm {
 pub struct Spot {
 	pub border: Style,
 	pub title:  Style,
+
+	pub tbl_col:  Style,
+	pub tbl_cell: Style,
 }
 
 #[derive(Deserialize, Serialize)]
@@ -166,7 +178,7 @@ pub struct Input {
 }
 
 #[derive(Deserialize, Serialize)]
-pub struct Completion {
+pub struct Cmp {
 	pub border:   Style,
 	pub active:   Style,
 	pub inactive: Style,
