@@ -1,19 +1,20 @@
-use yazi_shared::{event::Cmd, render};
+use yazi_macro::render;
+use yazi_shared::event::CmdCow;
 
-use crate::input::{op::InputOp, Input};
+use crate::input::{Input, op::InputOp};
 
-pub struct Opt {
+struct Opt {
 	cut:    bool,
 	insert: bool,
 }
 
-impl From<Cmd> for Opt {
-	fn from(c: Cmd) -> Self { Self { cut: c.bool("cut"), insert: c.bool("insert") } }
+impl From<CmdCow> for Opt {
+	fn from(c: CmdCow) -> Self { Self { cut: c.bool("cut"), insert: c.bool("insert") } }
 }
 
 impl Input {
-	pub fn delete(&mut self, opt: impl Into<Opt>) {
-		let opt = opt.into() as Opt;
+	#[yazi_codegen::command]
+	pub fn delete(&mut self, opt: Opt) {
 		match self.snap().op {
 			InputOp::None => {
 				self.snap_mut().op = InputOp::Delete(opt.cut, opt.insert, self.snap().cursor);
