@@ -1,20 +1,22 @@
-use yazi_shared::{event::Cmd, render};
+use yazi_macro::render;
+use yazi_shared::event::CmdCow;
 
-use crate::input::{op::InputOp, Input, InputMode};
+use crate::input::{Input, InputMode, op::InputOp};
 
-pub struct Opt {
+struct Opt {
 	append: bool,
 }
 
-impl From<Cmd> for Opt {
-	fn from(c: Cmd) -> Self { Self { append: c.bool("append") } }
+impl From<CmdCow> for Opt {
+	fn from(c: CmdCow) -> Self { Self { append: c.bool("append") } }
 }
 impl From<bool> for Opt {
 	fn from(append: bool) -> Self { Self { append } }
 }
 
 impl Input {
-	pub fn insert(&mut self, opt: impl Into<Opt>) {
+	#[yazi_codegen::command]
+	pub fn insert(&mut self, opt: Opt) {
 		let snap = self.snap_mut();
 		if snap.mode == InputMode::Normal {
 			snap.op = InputOp::None;
@@ -23,7 +25,6 @@ impl Input {
 			return;
 		}
 
-		let opt = opt.into() as Opt;
 		if opt.append {
 			self.move_(1);
 		}
