@@ -1,18 +1,20 @@
+use yazi_macro::render;
 use yazi_plugin::CLIPBOARD;
-use yazi_shared::{event::Cmd, render};
+use yazi_shared::event::CmdCow;
 
-use crate::input::{op::InputOp, Input};
+use crate::input::{Input, op::InputOp};
 
-pub struct Opt {
+struct Opt {
 	before: bool,
 }
 
-impl From<Cmd> for Opt {
-	fn from(c: Cmd) -> Self { Self { before: c.bool("before") } }
+impl From<CmdCow> for Opt {
+	fn from(c: CmdCow) -> Self { Self { before: c.bool("before") } }
 }
 
 impl Input {
-	pub fn paste(&mut self, opt: impl Into<Opt>) {
+	#[yazi_codegen::command]
+	pub fn paste(&mut self, opt: Opt) {
 		if let Some(start) = self.snap().op.start() {
 			self.snap_mut().op = InputOp::Delete(false, false, start);
 			self.handle_op(self.snap().cursor, true);
@@ -23,7 +25,6 @@ impl Input {
 			return;
 		}
 
-		let opt = opt.into() as Opt;
 		self.insert(!opt.before);
 		self.type_str(&s.to_string_lossy());
 		self.escape(());
