@@ -1,15 +1,14 @@
-use yazi_shared::{event::Cmd, render};
+use yazi_macro::render;
+use yazi_shared::event::{CmdCow, Data};
 
 use crate::tasks::Tasks;
 
-pub struct Opt {
+struct Opt {
 	step: isize,
 }
 
-impl From<Cmd> for Opt {
-	fn from(mut c: Cmd) -> Self {
-		Self { step: c.take_first().and_then(|s| s.parse().ok()).unwrap_or(0) }
-	}
+impl From<CmdCow> for Opt {
+	fn from(c: CmdCow) -> Self { Self { step: c.first().and_then(Data::as_isize).unwrap_or(0) } }
 }
 
 impl From<isize> for Opt {
@@ -17,9 +16,10 @@ impl From<isize> for Opt {
 }
 
 impl Tasks {
-	pub fn arrow(&mut self, opt: impl Into<Opt>) {
+	#[yazi_codegen::command]
+	pub fn arrow(&mut self, opt: Opt) {
 		let old = self.cursor;
-		if opt.into().step > 0 {
+		if opt.step > 0 {
 			self.cursor += 1;
 		} else {
 			self.cursor = self.cursor.saturating_sub(1);
