@@ -17,31 +17,36 @@ function Header:new(area, tab)
 	return setmetatable({
 		_area = area,
 		_tab = tab,
+		_current = tab.current,
 	}, { __index = self })
 end
 
 function Header:cwd()
 	local max = self._area.w - self._right_width
 	if max <= 0 then
-		return ui.Span("")
+		return ""
 	end
 
-	local s = ya.readable_path(tostring(self._tab.current.cwd)) .. self:flags()
-	return ui.Span(ya.truncate(s, { max = max, rtl = true })):style(THEME.manager.cwd)
+	local s = ya.readable_path(tostring(self._current.cwd)) .. self:flags()
+	return ui.Span(ya.truncate(s, { max = max, rtl = true })):style(th.mgr.cwd)
 end
 
 function Header:flags()
-	local cwd = self._tab.current.cwd
-	local filter = self._tab.current.files.filter
+	local cwd = self._current.cwd
+	local filter = self._current.files.filter
+	local finder = self._tab.finder
 
-	local s = cwd.is_search and string.format(" (search: %s", cwd:frag()) or ""
-	if not filter then
-		return s == "" and s or s .. ")"
-	elseif s == "" then
-		return string.format(" (filter: %s)", tostring(filter))
-	else
-		return string.format("%s, filter: %s)", s, tostring(filter))
+	local t = {}
+	if cwd.is_search then
+		t[#t + 1] = string.format("search: %s", cwd:frag())
 	end
+	if filter then
+		t[#t + 1] = string.format("filter: %s", filter)
+	end
+	if finder then
+		t[#t + 1] = string.format("find: %s", finder)
+	end
+	return #t == 0 and "" or " (" .. table.concat(t, ", ") .. ")"
 end
 
 function Header:count()
@@ -50,54 +55,57 @@ function Header:count()
 	local count, style
 	if yanked == 0 then
 		count = #self._tab.selected
-		style = THEME.manager.count_selected
+		style = th.mgr.count_selected
 	elseif cx.yanked.is_cut then
 		count = yanked
-		style = THEME.manager.count_cut
+		style = th.mgr.count_cut
 	else
 		count = yanked
-		style = THEME.manager.count_copied
+		style = th.mgr.count_copied
 	end
 
 	if count == 0 then
-		return ui.Line {}
+		return ""
 	end
 
 	return ui.Line {
 		ui.Span(string.format(" %d ", count)):style(style),
-		ui.Span(" "),
+		" ",
 	}
 end
 
 function Header:tabs()
 	local tabs = #cx.tabs
 	if tabs == 1 then
-		return ui.Line {}
+		return ""
 	end
 
 	local spans = {}
 	for i = 1, tabs do
 		local text = i
-		if THEME.manager.tab_width > 2 then
-			text = ya.truncate(text .. " " .. cx.tabs[i]:name(), { max = THEME.manager.tab_width })
+		if th.mgr.tab_width > 2 then
+			text = ya.truncate(text .. " " .. cx.tabs[i]:name(), { max = th.mgr.tab_width })
 		end
 		if i == cx.tabs.idx then
-			spans[#spans + 1] = ui.Span(" " .. text .. " "):style(THEME.manager.tab_active)
+			spans[#spans + 1] = ui.Span(" " .. text .. " "):style(th.mgr.tab_active)
 		else
-			spans[#spans + 1] = ui.Span(" " .. text .. " "):style(THEME.manager.tab_inactive)
+			spans[#spans + 1] = ui.Span(" " .. text .. " "):style(th.mgr.tab_inactive)
 		end
 	end
 	return ui.Line(spans)
 end
 
-function Header:render()
-	local right = self:children_render(self.RIGHT)
+function Header:reflow() return { self } end
+
+function Header:redraw()
+	local right = self:children_redraw(self.RIGHT)
 	self._right_width = right:width()
 
-	local left = self:children_render(self.LEFT)
+	local left = self:children_redraw(self.LEFT)
+
 	return {
-		ui.Paragraph(self._area, { left }),
-		ui.Paragraph(self._area, { right }):align(ui.Paragraph.RIGHT),
+		ui.Text(left):area(self._area),
+		ui.Text(right):area(self._area):align(ui.Text.RIGHT),
 	}
 end
 
@@ -129,7 +137,7 @@ function Header:children_remove(id, side)
 	end
 end
 
-function Header:children_render(side)
+function Header:children_redraw(side)
 	local lines = {}
 	for _, c in ipairs(side == self.RIGHT and self._right or self._left) do
 		lines[#lines + 1] = (type(c[1]) == "string" and self[c[1]] or c[1])(self)
