@@ -3,7 +3,7 @@ local M = {}
 function M:peek(job)
 	local err, bound = ya.preview_code(job)
 	if bound then
-		ya.manager_emit("peek", { bound, only_if = job.file.url, upper_bound = true })
+		ya.mgr_emit("peek", { bound, only_if = job.file.url, upper_bound = true })
 	elseif err and not err:find("cancelled", 1, true) then
 		require("empty").msg(job, err)
 	end
@@ -18,7 +18,7 @@ function M:seek(job)
 	local step = math.floor(job.units * job.area.h / 10)
 	step = step == 0 and ya.clamp(-1, job.units, 1) or step
 
-	ya.manager_emit("peek", {
+	ya.mgr_emit("peek", {
 		math.max(0, cx.active.preview.skip + step),
 		only_if = job.file.url,
 	})
