@@ -1,10 +1,10 @@
 #![allow(clippy::module_inception)]
 
-mod file;
+use mlua::Lua;
 
-pub use file::*;
+yazi_macro::mod_flat!(file);
 
-pub fn pour(lua: &mlua::Lua) -> mlua::Result<()> {
+pub fn pour(lua: &Lua) -> mlua::Result<()> {
 	file::File::register(lua)?;
 	file::File::install(lua)?;
 
