@@ -8,7 +8,6 @@ pub fn compose(lua: &Lua, isolate: bool) -> mlua::Result<Value> {
 	Composer::make(lua, 40, move |lua, key| {
 		match key {
 			// App
-			b"__250127" => Utils::hide(lua)?, // TODO: remove this
 			b"hide" => Utils::hide(lua)?,
 
 			// Cache
@@ -18,7 +17,8 @@ pub fn compose(lua: &Lua, isolate: bool) -> mlua::Result<Value> {
 			b"render" => Utils::render(lua)?,
 			b"redraw_with" => Utils::redraw_with(lua)?,
 			b"app_emit" => Utils::app_emit(lua)?,
-			b"manager_emit" => Utils::manager_emit(lua)?,
+			b"mgr_emit" => Utils::mgr_emit(lua)?,
+			b"manager_emit" => Utils::mgr_emit(lua)?, // TODO: remove this in the future
 			b"input_emit" => Utils::input_emit(lua)?,
 
 			// Image
