@@ -13,6 +13,9 @@ impl Urn {
 	#[inline]
 	pub fn name(&self) -> Option<&OsStr> { self.0.file_name() }
 
+	#[inline]
+	pub fn encoded_bytes(&self) -> &[u8] { self.0.as_os_str().as_encoded_bytes() }
+
 	#[cfg(unix)]
 	#[inline]
 	pub fn is_hidden(&self) -> bool {
@@ -52,6 +55,10 @@ impl Borrow<Urn> for UrnBuf {
 	fn borrow(&self) -> &Urn { Urn::new(&self.0) }
 }
 
+impl AsRef<Urn> for UrnBuf {
+	fn as_ref(&self) -> &Urn { self.borrow() }
+}
+
 impl AsRef<Path> for UrnBuf {
 	fn as_ref(&self) -> &Path { &self.0 }
 }
